@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: stat.graph.php 22040 2013-10-18 09:57:40Z yllen $
+ * @version $Id: stat.graph.php 22785 2014-03-14 10:50:11Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -334,8 +334,8 @@ $values['late']   = Stat::constructEntryValues($_GET['itemtype'], "inter_solved_
                                                $_GET["date1"], $_GET["date2"], $_GET["type"],
                                                $val1, $val2);
 
-$available = array('total'  => __('Opened'),
-                   'solved' => __('Solved'),
+$available = array('total'  => _nx('ticket','Opened','Opened',2),
+                   'solved' => _nx('ticket','Solved', 'Solved', 2),
                    'late'   => __('Late'),
                    'closed' => __('Closed'),);
 echo "<div class='center'>";
@@ -441,8 +441,8 @@ if ($_GET['itemtype'] == 'Ticket') {
                                                               $_GET["type"], $val1, $val2);
 
 
-   $available = array('opensatisfaction'   => __('Opened'),
-                     'answersatisfaction'  => __('Answered'));
+   $available = array('opensatisfaction'   => _nx('survey','Opened','Opened', 2),
+                     'answersatisfaction'  => _nx('survey','Answered','Answered',2));
    echo "<div class='center'>";
 
    foreach ($available as $key => $name) {
