@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: auth.class.php 20145 2013-02-05 19:17:11Z yllen $
+ * @version $Id: auth.class.php 22989 2014-06-04 06:38:12Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -543,7 +543,8 @@ class Auth {
 
       // If not already auth
       if (!$this->auth_succeded) {
-         if (empty($login_name) || empty($login_password)) {
+         if (empty($login_name) || strstr($login_name, "\0")
+             || empty($login_password) || strstr($login_password, "\0")) {
             $this->addToError(__('Empty login or password'));
          } else {
             // exists=0 -> user doesn't yet exist
