@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: autoload.function.php 22657 2014-02-12 16:17:54Z moyo $
+ * @version $Id: autoload.function.php 23191 2014-10-16 17:00:12Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2014 by the INDEPNET Development Team.
@@ -352,6 +352,11 @@ class SimplePie_Autoloader {
    **/
    public function autoload($class) {
 
+      // empty classname or non concerted plugin or classname containing dot (leaving GLPI main treee)
+      if (empty($class) || is_numeric($class) || (strpos($class, '.') !== false)) {
+         return false;
+      }
+      
       // Only load the class if it starts with "SimplePie"
       if (strpos($class, 'SimplePie') !== 0) {
          return;
