@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: bookmark.class.php 21782 2013-09-14 09:15:38Z moyo $
+ * @version $Id: bookmark.class.php 22724 2014-02-26 17:44:56Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -82,7 +82,7 @@ class Bookmark extends CommonDBTM {
                   && Session::haveRight('bookmark_public', 'w')
                   && Session::haveAccessToEntity($this->fields['entities_id'])));
    }
-   
+
    function isNewItem() {
       /// For tabs management : force isNewItem
       return false;
@@ -572,7 +572,7 @@ class Bookmark extends CommonDBTM {
          echo "<table class='tab_cadre_fixehov'>";
          echo "<tr>";
          echo "<th>".Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand)."</th>";
-         echo "<th class='center' colspan='2'>".__('Bookmarks')."</th>";
+         echo "<th class='center' colspan='2'>"._n('Bookmark', 'Bookmarks', 2)."</th>";
          echo "<th width='20px'>&nbsp;</th>";
          echo "<th>".__('Default view')."</th></tr>";
 
