@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: commontreedropdown.class.php 20643 2013-04-04 17:05:46Z yllen $
+ * @version $Id: commontreedropdown.class.php 23032 2014-06-20 07:12:27Z ddurieux $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -175,7 +175,7 @@ abstract class CommonTreeDropdown extends CommonDropdown {
          }
          // Parent changes => clear ancestors and update its level and completename
          if ($input[$this->getForeignKeyField()] != $this->fields[$this->getForeignKeyField()]) {
-            $input["ancestors_cache"] = NULL;
+            $input["ancestors_cache"] = '';
             return $this->adaptTreeFieldsFromUpdateOrAdd($input);
          }
       }
@@ -323,7 +323,7 @@ abstract class CommonTreeDropdown extends CommonDropdown {
             Log::history($ID, $this->getType(), $changes, $this->getType(),
                          Log::HISTORY_UPDATE_SUBITEM);
          }
-
+         getAncestorsOf(getTableForItemType($this->getType()), $ID);
       }
    }
 
