@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer.class.php 22657 2014-02-12 16:17:54Z moyo $
+ * @version $Id: computer.class.php 23118 2014-08-08 08:20:03Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2014 by the INDEPNET Development Team.
@@ -371,7 +371,7 @@ class Computer extends CommonDBTM {
 
       $ip = new Item_Problem();
       $ip->cleanDBonItemDelete('Computer', $this->fields['id']);
-      
+
       $ci = new Computer_Item();
       $ci->cleanDBonItemDelete('Computer', $this->fields['id']);
 
@@ -1003,7 +1003,7 @@ class Computer extends CommonDBTM {
 
       $tab[150]['table']         = 'glpi_computerdisks';
       $tab[150]['field']         = 'totalsize';
-      $tab[150]['name']          = __('Global size');
+      $tab[150]['name']          = sprintf(__('%1$s (%2$s)'),__('Global size'),__('Mio'));
       $tab[150]['forcegroupby']  = true;
       $tab[150]['usehaving']     = true;
       $tab[150]['datatype']      = 'number';
