@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: computer_item.class.php 21874 2013-09-25 06:45:28Z moyo $
+ * @version $Id: computer_item.class.php 22962 2014-04-28 20:00:02Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -626,7 +626,7 @@ class Computer_Item extends CommonDBRelation{
 
             if ($canedit) {
                echo "<td width='10'>";
-               Html::showMassiveActionCheckBox(__CLASS__, $data["id"]);
+               Html::showMassiveActionCheckBox(__CLASS__, $key);
                echo "</td>";
             }
             echo "<td ".
@@ -651,8 +651,8 @@ class Computer_Item extends CommonDBRelation{
 
       echo "</table>";
       if ($canedit && $number) {
-         $paramsma['ontop'] = false;
-         Html::showMassiveActions(__CLASS__, $paramsma);
+         $massiveactionparams['ontop'] = false;
+         Html::showMassiveActions(__CLASS__, $massiveactionparams);
          Html::closeForm();
       }
       echo "</div>";
