@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: computer_softwareversion.class.php 21179 2013-06-25 07:08:30Z moyo $
+ * @version $Id: computer_softwareversion.class.php 22970 2014-05-09 14:56:59Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -434,7 +434,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
             if ($canedit) {
                $rand = mt_rand();
                Html::openMassiveActionsForm('mass'.__CLASS__.$rand);
-               $paramsma = array('num_displayed' => $_SESSION['glpilist_limit'],
+               $paramsma = array('num_displayed' => $number,
                                  'specific_actions' => array('move_version'
                                                                      => _x('button', 'Move'),
                                                              'purge' => _x('button',
@@ -645,7 +645,7 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       if (Plugin::haveImport()) {
          $add_dynamic = "`glpi_computers_softwareversions`.`is_dynamic`,";
       }
-      
+
       $query = "SELECT `glpi_softwares`.`softwarecategories_id`,
                        `glpi_softwares`.`name` AS softname,
                        `glpi_computers_softwareversions`.`id`,
@@ -975,14 +975,14 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       }
 
       echo "</td>";
-      
+
       echo "</td>";
       if (isset($data['is_dynamic'])) {
          echo "<td class='center'>";
          echo Dropdown::getYesNo($data['is_dynamic']);
          echo "</td>";
-      }  
-      
+      }
+
       echo "</tr>\n";
 
       return $licids;
@@ -1007,9 +1007,9 @@ class Computer_SoftwareVersion extends CommonDBRelation {
       } else {
          $version = $data["softwareversions_id_buy"];
       }
-      
+
       $ID = $data['linkID'];
-      
+
       $multiple  = false;
       $link_item = Toolbox::getItemTypeFormURL('SoftwareLicense');
       $link      = $link_item."?id=".$data['id'];
