@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: contract.class.php 22128 2013-10-28 09:13:43Z moyo $
+ * @version $Id: contract.class.php 23027 2014-06-18 08:08:13Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -203,7 +203,7 @@ class Contract extends CommonDBTM {
                             array(0 => Dropdown::EMPTY_VALUE), array('unit' => 'month'));
       if (!empty($this->fields["begin_date"])) {
          echo " -> ".Infocom::getWarrantyExpir($this->fields["begin_date"],
-                                               $this->fields["duration"], 0, true);
+                                              $this->fields["duration"], 0, true);
       }
       echo "</td>";
       echo "</tr>";
@@ -324,6 +324,10 @@ class Contract extends CommonDBTM {
                                          'beforejoin' => array('table'      => 'glpi_contracts',
                                                                'joinparams' => $joinparams));
 
+      $joinparamstype            = array('beforejoin' => array('table'      => 'glpi_contracts',
+                  'joinparams' => $joinparams));
+
+
       $tab[139]['table']         = 'glpi_contracts_items';
       $tab[139]['field']         = 'count';
       $tab[139]['name']          = _x('quantity', 'Number of contracts');
@@ -349,6 +353,14 @@ class Contract extends CommonDBTM {
       $tab[30]['joinparams']     = $joinparams;
       $tab[30]['datatype']       = 'string';
 
+      $tab[129]['table']          = 'glpi_contracttypes';
+      $tab[129]['field']          = 'name';
+      $tab[129]['name']           = sprintf(__('%1$s - %2$s'), __('Contract'), __('Type'));
+      $tab[129]['datatype']       = 'dropdown';
+      $tab[129]['massiveaction']  = false;
+      $tab[129]['joinparams']     = array('beforejoin' => array('table'      => 'glpi_contracts',
+                                          'joinparams' => $joinparams));
+
       $tab[130]['table']         = 'glpi_contracts';
       $tab[130]['field']         = 'duration';
       $tab[130]['name']          = sprintf(__('%1$s - %2$s'), __('Contract'),__('Duration'));
@@ -972,6 +984,7 @@ class Contract extends CommonDBTM {
                $message = sprintf(__('%1$s: %2$s')."<br>\n", $data["name"],
                                   Infocom::getWarrantyExpir($data["begin_date"],
                                                             $data["duration"], $data["notice"]));
+               $data['items']      = Contract_Item::getItemsForContract($data['id'], $entity);
                $contract_infos[$type][$entity][$data['id']] = $data;
 
                if (!isset($contract_messages[$type][$entity])) {
@@ -1047,9 +1060,7 @@ class Contract extends CommonDBTM {
                                                 strtotime($next_alerts[$type]." +".($before)." day"));
                      $message            = sprintf(__('%1$s: %2$s')."<br>\n",
                                                  $data["name"], Html::convDate($real_alert_date));
-                     $data['alert_date'] = $real_alert_date;
-                     $data['items']      = Contract_Item::getItemsForContract($data['id'], $entity);
-                     $contract_infos[$type][$entity][$data['id']] = $data;
+                     $contract_infos[$type][$entity][$data['id']]['alert_date'] = $real_alert_date;
 
                      switch ($type) {
                         case 'periodicitynotice' :
@@ -1257,6 +1268,9 @@ class Contract extends CommonDBTM {
    static function getContractRenewalName($value) {
 
       switch ($value) {
+         case 0 :
+            return __('Never');
+
          case 1 :
             return __('Tacit');
 
