@@ -1,10 +1,10 @@
 <?php
 
 /*
- * @version $Id: crontask.class.php 20129 2013-02-04 16:53:59Z moyo $
+ * @version $Id: crontask.class.php 22915 2014-04-16 12:01:59Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -1303,7 +1303,11 @@ class CronTask extends CommonDBTM{
    static function cronSession($task) {
 
       // max time to keep the file session
-      $maxlifetime = session_cache_expire();
+      $maxlifetime = ini_get('session.gc_maxlifetime');
+      if ($maxlifetime==0) {
+         $maxlifetime == WEEK_TIMESTAMP;
+      }
+
       $nb          = 0;
       foreach (glob(GLPI_SESSION_DIR."/sess_*") as $filename) {
          if ((filemtime($filename) + $maxlifetime) < time()) {
