@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: entity.class.php 21841 2013-09-19 15:12:10Z yllen $
+ * @version $Id: entity.class.php 22696 2014-02-26 09:53:21Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -63,12 +63,14 @@ class Entity extends CommonTreeDropdown {
                                                    'authldaps_id', 'entity_ldapfilter', 'ldap_dn',
                                                    'mail_domain', 'tag',
                                                    // Inventory
-                                                   'autofill_buy_date', 'autofill_delivery_date',
-                                                   'autofill_order_date', 'autofill_use_date',
-                                                   'autofill_warranty_date',
                                                    'entities_id_software', 'level', 'name',
                                                    'completename', 'entities_id',
                                                    'ancestors_cache', 'sons_cache', 'comment'),
+                                       // Inventory
+                                       'infocom'
+                                          => array('autofill_buy_date', 'autofill_delivery_date',
+                                                   'autofill_order_date', 'autofill_use_date',
+                                                   'autofill_warranty_date'),
                                        // Notification
                                        'notification'
                                           => array('admin_email', 'admin_reply', 'admin_email_name',
@@ -1561,7 +1563,7 @@ class Entity extends CommonTreeDropdown {
     * @since version 0.84 (before in entitydata.class)
     *
     * @param $field
-    * @param $value
+    * @param $value must be addslashes
    **/
    private static function getEntityIDByField($field,$value) {
       global $DB;
