@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: ipaddress.class.php 21929 2013-10-02 10:51:49Z moyo $
+ * @version $Id: ipaddress.class.php 22657 2014-02-12 16:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -935,8 +935,19 @@ class IPAddress extends CommonDBChild {
 
       $addressesWithItems = self::getItemsByIPAddress($value);
 
+      // Filter : Do not keep ip not linked to asset
+      if (count($addressesWithItems)) {
+         foreach ($addressesWithItems as $key => $tab) {
+            if (isset($tab[0])
+                  && (($tab[0] instanceof NetworkName)
+                  || ($tab[0] instanceof IPAddress)
+                  || ($tab[0] instanceof NetworkPort))) { 
+               unset($addressesWithItems[$key]);
+            }
+         }
+      }
       if (count($addressesWithItems) == 1) {
-         $addressWithItems = $addressesWithItems[0];
+         $addressWithItems = current($addressesWithItems);
          $item             = $addressWithItems[0];
          if ($item->getEntityID() == $entity) {
             $result = array("id"       => $item->getID(),
