@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: knowbaseitem.class.php 22040 2013-10-18 09:57:40Z yllen $
+ * @version $Id: knowbaseitem.class.php 22657 2014-02-12 16:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -1029,31 +1029,33 @@ class KnowbaseItem extends CommonDBTM {
          default :
             // Build query
             if (Session::getLoginUserID() && $type != 'myunpublished') {
-               $where = self::addVisibilityRestrict()." AND ";
+               $where = self::addVisibilityRestrict();
             } else {
                // Anonymous access
                if (Session::isMultiEntitiesMode()) {
                   $where = " (`glpi_entities_knowbaseitems`.`entities_id` = '0'
-                              AND `glpi_entities_knowbaseitems`.`is_recursive` = '1')
-                           AND ";
+                              AND `glpi_entities_knowbaseitems`.`is_recursive` = '1')";
                }
             }
             break;
       }
 
+      if (empty($where)) {
+         $where = '1 = 1';
+      }
+      
       if ($params['faq']) { // helpdesk
-         $where .= " (`glpi_knowbaseitems`.`is_faq` = '1')
-                      AND ";
+         $where .= " AND (`glpi_knowbaseitems`.`is_faq` = '1')";
       }
 
       // a search with $contains
       switch ($type) {
          case 'allmy' :
-            $where .= "`glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."'";
+            $where .= " AND `glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."'";
             break;
 
          case 'myunpublished' :
-            $where .= "`glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."'
+            $where .= " AND `glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."'
                         AND (`glpi_entities_knowbaseitems`.`entities_id` IS NULL
                               AND `glpi_knowbaseitems_profiles`.`profiles_id` IS NULL
                               AND `glpi_groups_knowbaseitems`.`groups_id` IS NULL
@@ -1062,7 +1064,7 @@ class KnowbaseItem extends CommonDBTM {
 
          case 'allunpublished' :
             // Only published
-            $where .= "(`glpi_entities_knowbaseitems`.`entities_id` IS NULL
+            $where .= " AND (`glpi_entities_knowbaseitems`.`entities_id` IS NULL
                               AND `glpi_knowbaseitems_profiles`.`profiles_id` IS NULL
                               AND `glpi_groups_knowbaseitems`.`groups_id` IS NULL
                               AND `glpi_knowbaseitems_users`.`users_id` IS NULL)";
@@ -1075,7 +1077,7 @@ class KnowbaseItem extends CommonDBTM {
                $score   = " ,MATCH(`glpi_knowbaseitems`.`name`, `glpi_knowbaseitems`.`answer`)
                            AGAINST('$search' IN BOOLEAN MODE) AS SCORE ";
 
-               $where_1 = $where." MATCH(`glpi_knowbaseitems`.`name`, `glpi_knowbaseitems`.`answer`)
+               $where_1 = $where." AND MATCH(`glpi_knowbaseitems`.`name`, `glpi_knowbaseitems`.`answer`)
                           AGAINST('$search' IN BOOLEAN MODE) ";
 
                $order   = "ORDER BY `SCORE` DESC";
@@ -1099,7 +1101,7 @@ class KnowbaseItem extends CommonDBTM {
                                    /* 8 */   "/\)/",
                                    /* 9 */   "/\-/");
                   $contains = preg_replace($search1,"", $params["contains"]);
-                  $where   .= " (`glpi_knowbaseitems`.`name` ".Search::makeTextSearch($contains)."
+                  $where   .= " AND (`glpi_knowbaseitems`.`name` ".Search::makeTextSearch($contains)."
                                  OR `glpi_knowbaseitems`.`answer` ".Search::makeTextSearch($contains).")";
                } else {
                   $where = $where_1;
@@ -1108,8 +1110,8 @@ class KnowbaseItem extends CommonDBTM {
             break;
 
          case 'browse' :
-            $where .= " (`glpi_knowbaseitems`.`knowbaseitemcategories_id`
-                           = '".$params["knowbaseitemcategories_id"]."')";
+            $where .= " AND (`glpi_knowbaseitems`.`knowbaseitemcategories_id`
+                             = '".$params["knowbaseitemcategories_id"]."')";
             $order  = " ORDER BY `glpi_knowbaseitems`.`name` ASC";
             break;
       }
