@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkport.class.php 22918 2014-04-16 13:37:20Z moyo $
+ * @version $Id: networkport.class.php 23165 2014-09-18 08:11:52Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2014 by the INDEPNET Development Team.
@@ -1157,18 +1157,20 @@ class NetworkPort extends CommonDBChild {
             $np->fields["items_id"] = $new_items_id;
             $portid                 = $np->addToDB();
 
-            $instantiation = $np->getInstantiation();
-            if ($instantiation !== false) {
-               $instantiation->add(array('id' => $portid));
-               unset($instantiation);
-            }
+            
+            /// Duplicate instantiation infos ? needed ? this code do not duplicate only create empty one
+//             $instantiation = $np->getInstantiation();
+//             if ($instantiation !== false) {
+//                $instantiation->add(array('networkports_id' => $portid));
+//                unset($instantiation);
+//             }
 
             $npv = new NetworkPort_Vlan();
             foreach ($DB->request($npv->getTable(),
-                                  array($npv->items_id_1 => $data["id"])) as $vlan) {
+                                  array($npv::$items_id_1 => $data["id"])) as $vlan) {
 
-               $input = array($npv->items_id_1 => $portid,
-                              $npv->items_id_2 => $vlan['vlans_id']);
+               $input = array($npv::$items_id_1 => $portid,
+                              $npv::$items_id_2 => $vlan['vlans_id']);
                if (isset($vlan['tagged'])) {
                   $input['tagged'] = $vlan['tagged'];
                }
