@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: notificationtarget.class.php 21578 2013-08-27 10:09:39Z moyo $
+ * @version $Id: notificationtarget.class.php 23070 2014-07-10 17:02:17Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -112,6 +112,9 @@ class NotificationTarget extends CommonDBChild {
       $this->options    = $options;
       $this->getNotificationTargets($entity);
       $this->getAdditionalTargets($event);
+      // add new target by plugin
+      unset($this->data);
+      Plugin::doHook('item_add_targets', $this);
       asort($this->notification_targets);
    }
 
@@ -134,7 +137,7 @@ class NotificationTarget extends CommonDBChild {
     * @return true
    **/
    function validateSendTo($event, array $infos, $notify_me=false) {
-      
+
       if (!$notify_me) {
          if (isset($infos['users_id'])
              // Check login user and not event launch by crontask
@@ -1002,7 +1005,7 @@ class NotificationTarget extends CommonDBChild {
          case Notification::GROUP_WITHOUT_SUPERVISOR_TYPE :
             $this->getAddressesByGroup(2, $data['items_id']);
             break;
-            
+
          //Send to all the users of a profile
          case Notification::PROFILE_TYPE :
             $this->getUsersAddressesByProfile($data['items_id']);
@@ -1012,6 +1015,9 @@ class NotificationTarget extends CommonDBChild {
             //Maybe a target specific to a type
             $this->getSpecificTargets($data,$options);
       }
+      // action for target from plugin
+      $this->data = $data;
+      Plugin::doHook('item_action_targets',$this);
    }
 
 
