@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtemplatetranslation.class.php 22657 2014-02-12 16:17:54Z moyo $
+ * @version $Id: notificationtemplatetranslation.class.php 23091 2014-07-22 08:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2014 by the INDEPNET Development Team.
@@ -139,7 +139,7 @@ class NotificationTemplateTranslation extends CommonDBChild {
 
       echo "<tr class='tab_bg_1'><td>" . __('Subject') . "</td>";
       echo "<td colspan='3'>";
-      echo "<input type='text' name='subject'size='100' value='".$this->fields["subject"]."'>";
+      Html::autocompletionTextField($this,'subject', array('size' => 100));
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'><td>";
