@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: plugin.class.php 21447 2013-08-01 12:17:20Z yllen $
+ * @version $Id: plugin.class.php 22808 2014-03-20 16:40:12Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -382,7 +382,7 @@ class Plugin extends CommonDBTM {
             echo "</td><td>";
             switch ($plug['state']) {
                case self::ANEW :
-                  echo _x('plugin', 'New');
+                  echo _x('status', 'New');
                   break;
 
                case self::ACTIVATED :
