@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: printer.class.php 20532 2013-03-29 08:01:35Z moyo $
+ * @version $Id: printer.class.php 22657 2014-02-12 16:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -487,16 +487,23 @@ class Printer  extends CommonDBTM {
 
 
    /**
-    * Return the SQL command to retrieve linked object
+    * Return the linked items (in computers_items)
     *
-    * @return a SQL command which return a set of (itemtype, items_id)
-    **/
-   function getSelectLinkedItem() {
+    * @return an array of linked items  like array('Computer' => array(1,2), 'Printer' => array(5,6))
+    * @since version 0.84.4
+   **/
+   function getLinkedItems() {
+      global $DB;
 
-      return "SELECT 'Computer', `computers_id`
+      $query = "SELECT 'Computer', `computers_id`
               FROM `glpi_computers_items`
               WHERE `itemtype` = '".$this->getType()."'
                     AND `items_id` = '" . $this->fields['id']."'";
+      $tab = array();
+      foreach ($DB->request($query) as $data) {
+         $tab['Computer'][$data['computers_id']] = $data['computers_id'];
+      };
+      return $tab;
    }
 
 
