@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: problem.class.php 22021 2013-10-17 07:45:54Z yllen $
+ * @version $Id: problem.class.php 22808 2014-03-20 16:40:12Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -717,20 +717,20 @@ class Problem extends CommonITILObject {
    static function getAllStatusArray($withmetaforsearch=false) {
 
       // To be overridden by class
-      $tab = array(self::INCOMING => _x('problem', 'New'),
-                   self::ACCEPTED => _x('problem', 'Accepted'),
-                   self::ASSIGNED => _x('problem', 'Processing (assigned)'),
-                   self::PLANNED  => _x('problem', 'Processing (planned)'),
+      $tab = array(self::INCOMING => _x('status', 'New'),
+                   self::ACCEPTED => _x('status', 'Accepted'),
+                   self::ASSIGNED => _x('status', 'Processing (assigned)'),
+                   self::PLANNED  => _x('status', 'Processing (planned)'),
                    self::WAITING  => __('Pending'),
-                   self::SOLVED   => _x('problem', 'Solved'),
+                   self::SOLVED   => _x('status', 'Solved'),
                    self::OBSERVED => __('Under observation'),
-                   self::CLOSED   => _x('problem', 'Closed'));
+                   self::CLOSED   => _x('status', 'Closed'));
 
       if ($withmetaforsearch) {
-         $tab['notold']    = _x('problem', 'Not solved');
-         $tab['notclosed'] = _x('problem', 'Not closed');
+         $tab['notold']    = _x('status', 'Not solved');
+         $tab['notclosed'] = _x('status', 'Not closed');
          $tab['process']   = __('Processing');
-         $tab['old']       = _x('problem', 'Solved + Closed');
+         $tab['old']       = _x('status', 'Solved + Closed');
          $tab['all']       = __('All');
       }
       return $tab;
@@ -1895,13 +1895,13 @@ class Problem extends CommonITILObject {
                //        %2$s is the name of the item (used for headings of a list)
                                         sprintf(__('%1$s = %2$s'), $item->getTypeName(1),
                                                 $item->getName()));
-
+         $colspan = 9;
          if (count($_SESSION["glpiactiveentities"]) > 1) {
-            echo "<tr><th colspan='9'>";
-         } else {
-            echo "<tr><th colspan='8'>";
+            $colspan++;
          }
 
+         echo "<tr><th colspan='$colspan'>";
+
          //TRANS : %d is the number of problems
          echo sprintf(_n('Last %d problem','Last %d problems',$number), $number);
 //             echo "<span class='small_space'><a href='".$CFG_GLPI["root_doc"]."/front/ticket.php?".
@@ -1925,14 +1925,24 @@ class Problem extends CommonITILObject {
 
       echo "</table></div>";
 
-      // Tickets for linked items
-      if ($subquery = $item->getSelectLinkedItem()) {
+      // Problems for linked items
+      $linkeditems = $item->getLinkedItems();
+      $restrict = array();
+      if (count($linkeditems)) {
+         foreach ($linkeditems as $ltype => $tab) {
+            foreach ($tab as $lID) {
+               $restrict[] = "(`itemtype` = '$ltype' AND `items_id` = '$lID')";
+            }
+         }
+      }
+
+      if (count($restrict)) {
          $query = "SELECT ".self::getCommonSelect()."
                    FROM `glpi_problems`
                    LEFT JOIN `glpi_items_problems`
                         ON (`glpi_problems`.`id` = `glpi_items_problems`.`problems_id`) ".
                    self::getCommonLeftJoin()."
-                   WHERE (`itemtype`,`items_id`) IN (" . $subquery . ")".
+                   WHERE ".implode(' OR ', $restrict).
                          getEntitiesRestrictRequest(' AND ', 'glpi_problems') . "
                    ORDER BY `glpi_problems`.`date_mod` DESC
                    LIMIT ".intval($_SESSION['glpilist_limit']);
@@ -1940,7 +1950,7 @@ class Problem extends CommonITILObject {
          $number = $DB->numrows($result);
 
          echo "<div class='spaced'><table class='tab_cadre_fixe'>";
-         echo "<tr><th colspan='8'>";
+         echo "<tr><th colspan='$colspan'>";
          _e('Problems on linked items');
 
          echo "</th></tr>";
