@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: profile.class.php 21900 2013-09-26 20:10:39Z tsmr $
+ * @version $Id: profile.class.php 22657 2014-02-12 16:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -578,6 +578,10 @@ class Profile extends CommonDBTM {
       if (Session::isMultiEntitiesMode()) {
          $options['condition'] = '`is_recursive` = 1';
       }
+      // Only add profile if on root entity
+      if (!isset($_SESSION['glpiactiveentities'][0])) {
+         $options['addicon'] = false;
+      }      
       TicketTemplate::dropdown($options);
       echo "</td>";
       echo "<td>".__('Add a followup to tickets of associated groups')."</td><td>";
@@ -865,7 +869,10 @@ class Profile extends CommonDBTM {
       if (Session::isMultiEntitiesMode()) {
          $options['condition'] = '`is_recursive` = 1';
       }
-
+      // Only add profile if on root entity
+      if (!isset($_SESSION['glpiactiveentities'][0])) {
+         $options['addicon'] = false;
+      }
 
       TicketTemplate::dropdown($options);
       echo "</td>";
