@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: rule.class.php 21806 2013-09-18 06:23:07Z moyo $
+ * @version $Id: rule.class.php 22964 2014-04-28 20:03:48Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -2434,7 +2434,7 @@ class Rule extends CommonDBTM {
                                                             = '".$item->getID()."'");
                   }
 
-                  return self::createTabEntry(self::getTypeName(2), 2);
+                  return self::createTabEntry(self::getTypeName(2), $nb);
                }
                return $this->getTypeName(2);
 
