@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: ruledictionnarysoftwarecollection.class.php 20580 2013-03-29 18:09:43Z moyo $
+ * @version $Id: ruledictionnarysoftwarecollection.class.php 22657 2014-02-12 16:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -38,28 +38,12 @@ class RuleDictionnarySoftwareCollection extends RuleCollection {
    // From RuleCollection
 
    public $stop_on_first_match = true;
+   public $can_replay_rules    = true;
    static public $right        = 'rule_dictionnary_software';
    public $menu_type           = 'dictionnary';
    public $menu_option         = 'software';
 
 
-//    /**
-//     * Constructor
-//    **/
-//    function __construct() {
-// 
-//       //Init cache system values
-//       $this->initCache("glpi_rulecachesoftwares", array("name"         => "old_value",
-//                                                         "manufacturer" => "manufacturer",
-//                                                         "entities_id"  => "entities_id"),
-//                        array("name"                => "new_value",
-//                              "version"             => "version",
-//                              "manufacturer"        => "new_manufacturer",
-//                              "is_helpdesk_visible" => "is_helpdesk_visible",
-//                              "_ignore_import"      => "ignore_import",
-//                              "new_entities_id"     => "new_entities_id"));
-//    }
-
 
    /**
     * @see RuleCollection::getTitle()
@@ -138,7 +122,8 @@ class RuleDictionnarySoftwareCollection extends RuleCollection {
          $sql = "SELECT DISTINCT `glpi_softwares`.`name`,
                         `glpi_manufacturers`.`name` AS manufacturer,
                         `glpi_softwares`.`manufacturers_id` AS manufacturers_id,
-                        `glpi_softwares`.`entities_id` AS entities_id
+                        `glpi_softwares`.`entities_id` AS entities_id,
+                        `glpi_softwares`.`is_helpdesk_visible` AS helpdesk
                  FROM `glpi_softwares`
                  LEFT JOIN `glpi_manufacturers`
                      ON (`glpi_manufacturers`.`id` = `glpi_softwares`.`manufacturers_id`)";
@@ -148,7 +133,7 @@ class RuleDictionnarySoftwareCollection extends RuleCollection {
                         AND `glpi_softwares`.`is_template` = '0' ";
 
          if (isset($params['manufacturer']) && $params['manufacturer']) {
-            $sql .= " AND `manufacturer` = '" . $params['manufacturer'] . "'";
+            $sql .= " AND `glpi_softwares`.`manufacturers_id` = '" . $params['manufacturer'] . "'";
          }
          if ($offset) {
             $sql .= " LIMIT " . intval($offset) . ",999999999";
@@ -179,7 +164,11 @@ class RuleDictionnarySoftwareCollection extends RuleCollection {
             if ((isset($res_rule["name"]) && ($res_rule["name"] != $input["name"]))
                 || (isset($res_rule["version"]) && ($res_rule["version"] != ''))
                 || (isset($res_rule['new_entities_id'])
-                    && ($res_rule['new_entities_id'] != $input['entities_id']))) {
+                    && ($res_rule['new_entities_id'] != $input['entities_id']))
+                || (isset($res_rule['is_helpdesk_visible'])
+                    && ($res_rule['is_helpdesk_visible'] != $input['helpdesk']))
+                || (isset($res_rule['manufacturer'])
+                    && ($res_rule['manufacturer'] != $input['manufacturer']))) {
 
                $IDs = array();
                //Find all the softwares in the database with the same name and manufacturer
