@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: session.class.php 21745 2013-09-11 16:58:11Z moyo $
+ * @version $Id: session.class.php 22824 2014-03-26 11:02:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -356,7 +356,7 @@ class Session {
                                                                __('tree structure'));
          }
 
-         if (countElementsInTable('glpi_entities') < count($_SESSION['glpiactiveentities'])) {
+         if (countElementsInTable('glpi_entities') <= count($_SESSION['glpiactiveentities'])) {
             $_SESSION['glpishowallentities'] = 1;
          } else {
             $_SESSION['glpishowallentities'] = 0;
