@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: ticketfollowup.class.php 22040 2013-10-18 09:57:40Z yllen $
+ * @version $Id: ticketfollowup.class.php 22657 2014-02-12 16:17:54Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -224,7 +224,9 @@ class TicketFollowup  extends CommonDBTM {
 
    function prepareInputForUpdate($input) {
 
-      if ($uid = Session::getLoginUserID()) {
+      // update writer if content change
+      if ($uid = Session::getLoginUserID() && isset($input['content'])
+         && ($input['content'] != $this->fields['content'])) {
          $input["users_id"] = $uid;
       }
       return $input;
@@ -711,7 +713,9 @@ class TicketFollowup  extends CommonDBTM {
 
       if (($ticket->fields["status"] == CommonITILObject::SOLVED)
           && $ticket->canApprove()
-          && $ticket->isAllowedStatus($ticket->fields['status'], Ticket::CLOSED)) {
+          && ($ticket->isAllowedStatus($ticket->fields['status'], Ticket::CLOSED)
+              || ($_SESSION['glpiactiveprofile']['interface'] == 'helpdesk'))) {
+
          echo "<form name='form' method='post' action='".$this->getFormURL()."'>";
          echo "<table class='tab_cadre_fixe'>";
          echo "<tr><th colspan='4'>". __('Approval of the solution')."</th></tr>";
