@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: toolbox.class.php 21949 2013-10-06 06:30:55Z remi $
+ * @version $Id: toolbox.class.php 22953 2014-04-25 15:08:33Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
+ Copyright (C) 2003-2014 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -390,6 +390,7 @@ class Toolbox {
 
       $config             = array('safe'=>1);
       $config["elements"] = "*+iframe";
+      $config["direct_list_nest"] = 1;
       $value              = htmLawed($value, $config);
 
       return $value;
@@ -1969,10 +1970,10 @@ class Toolbox {
 
       echo "<select name='server_cert'>";
       echo "<option value=''>&nbsp;</option>\n";
-      echo "<option value='/novalidate-cert' ".(($tab['validate-cert'] === true) ?" selected ":"");
+      echo "<option value='/novalidate-cert' ".(($tab['validate-cert'] === false) ?" selected ":"");
       //TRANS: imap_open option see http://www.php.net/manual/en/function.imap-open.php
       echo ">".__('NO-VALIDATE-CERT')."</option>\n";
-      echo "<option value='/validate-cert' " .(($tab['validate-cert'] === false) ?" selected ":"");
+      echo "<option value='/validate-cert' " .(($tab['validate-cert'] === true) ?" selected ":"");
       //TRANS: imap_open option see http://www.php.net/manual/en/function.imap-open.php
       echo ">".__('VALIDATE-CERT')."</option>\n";
       echo "</select>\n";
